""" for testing the attempt to copy rather than stream files """
import logging
from argparse import Namespace

# pylint: disable=C0103, C0301, E0401, E0402, R0201, R0902, R0903, W0621

from datafetcher.locations_report import LocationsReport
from datafetcher.project_fetcher import ParallelFetcher
from datafetcher.utilities import get_capo_settings, ExecutionSite
from datafetcher.errors import MissingSettingsException

from .df_pytest_utils import TEST_PROFILE

logger = logging.getLogger(__name__)


class MockProdDataFetcher:
    """ Creates and launches a datafetcher using the dsoc-prod profile """

    def __init__(self, args: Namespace, settings: dict):
        if args is None or settings is None:
            raise MissingSettingsException()
        self.args = args
        self.settings = settings

        self.output_dir = args.output_dir
        self.profile = args.profile

        self.locations_report = self._get_locations()
        self.servers_report = self.locations_report.servers_report

    def _get_locations(self):
        """
        Create a locations report with DSOC as exec site
            to force copy rather than stream
        :return:
        """

        capo_settings = get_capo_settings(TEST_PROFILE)
        capo_settings["execution_site"] = ExecutionSite.DSOC.value

        return LocationsReport(self.args, capo_settings)

    def run(self):
        """
        identical to DataFetcher.run()
        :return:
        """

        return ParallelFetcher(self.args, self.settings, self.servers_report).run()
