"""fixing error in download metrics

Revision ID: 32a78fe3bb5e
Revises: 1aee35976c94
Create Date: 2021-04-01 10:34:56.524285

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '32a78fe3bb5e'
down_revision = '1aee35976c94'
branch_labels = None
depends_on = None


def upgrade():

    op.execute("""
    CREATE OR REPLACE VIEW download_metrics AS
    SELECT ce.capability_request_id as request_id,
       cr.capability_name as cap_name,
       ce.created_at as execution_created,
       ce.state as state,
       cr.parameters->>'product_locator' as product_locator,
       sp.filegroup_id,
       (CASE when (f.datasize is not null AND f.datasize != '-1') then f.datasize
             when (sum(f2.datasize) is not null) then sum(f2.datasize)
             ELSE sum(f3.filesize) end)::BIGINT as datasize
    FROM capability_executions ce
         JOIN capability_requests cr on cr.capability_request_id = ce.capability_request_id
         JOIN science_products sp on parameters->>'product_locator' = sp.science_product_locator
         Left Outer JOIN filegroups f on sp.filegroup_id = f.filegroup_id
         Left Outer Join filegroups f2 on sp.filegroup_id = f2.parent_filegroup_id
         Left OUTER JOIN files f3 on sp.filegroup_id = f3.filegroup
    WHERE capability_name = 'test_download'
    GROUP BY ce.capability_request_id, cr.capability_name, ce.created_at, ce.state, cr.parameters->>'product_locator',
         sp.filegroup_id, f.datasize
    """)


def downgrade():
    op.execute("""
    DROP VIEW IF EXISTS download_metrics
    """)
