from __future__ import annotations

from typing import Dict, List

from workspaces.capability.helpers_interfaces import CapabilityStepIF, ParameterIF
from workspaces.products.schema_interfaces import FutureProductIF
from workspaces.system.schema import JSONSerializable
from workspaces.workflow.schema_interfaces import WorkflowRequestIF


class CapabilityIF(JSONSerializable):
    id: int
    name: str
    steps: List[CapabilityStepIF]
    max_jobs: int

    def create_request(
        self, parameters: ParameterIF, future_products: FutureProductIF
    ) -> "CapabilityRequestIF":
        raise NotImplementedError


class CapabilityRequestIF(JSONSerializable):
    id: int
    state: str
    capability: CapabilityIF
    parameters: str
    future_products: str
    versions: List[CapabilityVersionIF]


class CapabilityVersionIF:
    capability_request: CapabilityRequestIF
    version_number: int
    # eventually, the parameters should go here


class CapabilityExecutionIF:
    id: int
    capability_version: CapabilityVersionIF
    state: str
    current_step: int
    version: CapabilityVersionIF
    current_workflow_request_id: int
    steps: str
    capability: CapabilityIF
    capability_request: CapabilityRequestIF

    def on_last_step(self) -> bool:
        raise NotImplementedError

    def __json__(self):
        raise NotImplementedError
