import chevron
import sqlalchemy as sa
from sqlalchemy.ext.declarative import declarative_base
from typing import Dict
from workspaces.system.schema import AbstractFile

Base = declarative_base()


class NotificationTemplate(Base):
    """
    Notification Templates are Mustache-formatted files used for sending emails with the notification system.
    """

    __tablename__ = "notification_templates"
    name = sa.Column("name", sa.String, primary_key=True)
    description = sa.Column("description", sa.String, nullable=False)
    content = sa.Column("template", sa.String, nullable=False)

    def render(self, argument: Dict) -> AbstractFile:
        """
        Render a given Mustache-formatted Workflow Template with the specified arguments.

        :param argument:    argument(s) needed for template render
        :return:            an AbstractFile rendered from mustache template
        """

        # TODO: if template has more than one tag, figure out how pass argument parameter
        #  in as JSON and replace 'data' section accordingly
        args = {
            "template": self.content.decode("ascii"),
            "data": {"arguments": "".join(map(str, argument))},
        }
        contents = chevron.render(**args)
        return contents
